Learn R Programming

GSelection (version 0.1.0)

hsic.var.ensemble: Error Variance Estimation in Genomic Prediction

Description

Estimation of error variance using Ensemble method which combines bootstraping and sampling with srswor in HSIC LASSO.

Usage

hsic.var.ensemble(x,y,b,d)

Arguments

x

a matrix of markers or explanatory variables, each column contains one marker and each row represents an individual.

y

a column vector of response variable.

b

number of bootstrap samples.

d

number of variables to be selected from x.

Value

Error variance

Details

In this method, both bootstrapping and simple random sampling without replacement are combined to estimate error variance. Variables are selected using HSIC LASSO from the original datasets and all possible samples of a particular size are taken from the selected variables set with simple random sampling without replacement. With these selected samples error variance is estimated from bootstrap samples of the original datasets using least squared regression method. Finally the average of all the estimated variances is considered as the final estimate of the error variance.

References

Yamada, M., Jitkrittum, W., Sigal, L., Xing, E. P. and Sugiyama, M. (2014). High-Dimensional Feature Selection by Feature-Wise Kernelized Lasso. Neural Computation, 26(1):185-207. doi:10.1162/NECO_a_00537

Examples

Run this code
# NOT RUN {
library(GSelection)
data(GS)
x_trn <- GS[1:40,1:110]
y_trn <- GS[1:40,111]
x_tst <- GS[41:60,1:110]
y_tst <- GS[41:60,111]
hsic_var <- hsic.var.ensemble(x_trn,y_trn,2,10)
# }

Run the code above in your browser using DataLab